==> ejc-zjkjcost-impl-3.0.0-20220629.032646-20-sources.jar: com/ejianc/business/zjkjcost/optimization/bean/OptimizationTopicEntity.java <==
package com.ejianc.business.zjkjcost.optimization.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目优化-项目优化立项申报
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_optimization_topic")
public class OptimizationTopicEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="topic_name")
    private String topicName; // 立项名称
    @TableField(value="plan_term_start")
    private Date planTermStart; // 计划实施期限
    @TableField(value="plan_term_end")
    private Date planTermEnd; // 计划实施期限
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="topic_exec_user")
    private String topicExecUser; // 实施人员
    @TableField(value="brief_scheme")
    private String briefScheme; // 优化方案简要内容
    @TableField(value="income_basis")
    private String incomeBasis; // 预计收益及测算依据
    @TableField(value="manager_opinion")
    private String managerOpinion; // 项目经理意见
    @TableField(value="department_consent_flag")
    private Integer departmentConsentFlag; // 所属单位归口管理部门是否同意立项(0:同意，1:不同意)
    @TableField(value="department_opinion")
    private String departmentOpinion; // 所属单位归口管理部门指导意见
    @TableField(value="leader_consent_flag")
    private Integer leaderConsentFlag; // 所属单位归口管理部门分管领导是否同意立项(0:同意，1:不同意)
    @TableField(value="leader_opinion")
    private String leaderOpinion; // 所属单位归口管理部门分管领导指导意见
    @TableField(value="calculation_occupy_flag")
    private Integer calculationOccupyFlag; // 项目优化效益计算占用标志(0:未占用，1:已占用)
    @TableField(value="reward_occupy_flag")
    private Integer rewardOccupyFlag; // 项目优化奖励申请占用标志(0:未占用，1:已占用)
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getTopicName() {
        return topicName;
    }

    public void setTopicName(String topicName) {
        this.topicName = topicName;
    }

    public Date getPlanTermStart() {
        return planTermStart;
    }

    public void setPlanTermStart(Date planTermStart) {
        this.planTermStart = planTermStart;
    }

    public Date getPlanTermEnd() {
        return planTermEnd;
    }

    public void setPlanTermEnd(Date planTermEnd) {
        this.planTermEnd = planTermEnd;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getTopicExecUser() {
        return topicExecUser;
    }

    public void setTopicExecUser(String topicExecUser) {
        this.topicExecUser = topicExecUser;
    }
    public String getBriefScheme() {
        return briefScheme;
    }

    public void setBriefScheme(String briefScheme) {
        this.briefScheme = briefScheme;
    }
    public String getIncomeBasis() {
        return incomeBasis;
    }

    public void setIncomeBasis(String incomeBasis) {
        this.incomeBasis = incomeBasis;
    }
    public String getManagerOpinion() {
        return managerOpinion;
    }

    public void setManagerOpinion(String managerOpinion) {
        this.managerOpinion = managerOpinion;
    }
    public Integer getDepartmentConsentFlag() {
        return departmentConsentFlag;
    }

    public void setDepartmentConsentFlag(Integer departmentConsentFlag) {
        this.departmentConsentFlag = departmentConsentFlag;
    }
    public String getDepartmentOpinion() {
        return departmentOpinion;
    }

    public void setDepartmentOpinion(String departmentOpinion) {
        this.departmentOpinion = departmentOpinion;
    }
    public Integer getLeaderConsentFlag() {
        return leaderConsentFlag;
    }

    public void setLeaderConsentFlag(Integer leaderConsentFlag) {
        this.leaderConsentFlag = leaderConsentFlag;
    }
    public String getLeaderOpinion() {
        return leaderOpinion;
    }

    public void setLeaderOpinion(String leaderOpinion) {
        this.leaderOpinion = leaderOpinion;
    }
    public Integer getCalculationOccupyFlag() {
        return calculationOccupyFlag;
    }

    public void setCalculationOccupyFlag(Integer calculationOccupyFlag) {
        this.calculationOccupyFlag = calculationOccupyFlag;
    }
    public Integer getRewardOccupyFlag() {
        return rewardOccupyFlag;
    }

    public void setRewardOccupyFlag(Integer rewardOccupyFlag) {
        this.rewardOccupyFlag = rewardOccupyFlag;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20221019.100803-59-sources.jar: com/ejianc/business/zjkjcost/optimization/bean/OptimizationTopicEntity.java <==
package com.ejianc.business.zjkjcost.optimization.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import io.swagger.annotations.ApiModelProperty;

/**
 * 项目优化-项目优化立项申报
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_optimization_topic")
public class OptimizationTopicEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="topic_name")
    private String topicName; // 立项名称
    @TableField(value="plan_term_start")
    private Date planTermStart; // 计划实施期限
    @TableField(value="plan_term_end")
    private Date planTermEnd; // 计划实施期限
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="topic_exec_user")
    private String topicExecUser; // 实施人员
    @TableField(value="brief_scheme")
    private String briefScheme; // 优化方案简要内容
    @TableField(value="income_basis")
    private String incomeBasis; // 预计收益及测算依据
    @TableField(value="manager_opinion")
    private String managerOpinion; // 项目经理意见
    @TableField(value="department_consent_flag")
    private Integer departmentConsentFlag; // 所属单位归口管理部门是否同意立项(0:同意，1:不同意)
    @TableField(value="department_opinion")
    private String departmentOpinion; // 所属单位归口管理部门指导意见
    @TableField(value="leader_consent_flag")
    private Integer leaderConsentFlag; // 所属单位归口管理部门分管领导是否同意立项(0:同意，1:不同意)
    @TableField(value="leader_opinion")
    private String leaderOpinion; // 所属单位归口管理部门分管领导指导意见
    @TableField(value="calculation_occupy_flag")
    private Integer calculationOccupyFlag; // 项目优化效益计算占用标志(0:未占用，1:已占用)
    @TableField(value="reward_occupy_flag")
    private Integer rewardOccupyFlag; // 项目优化奖励申请占用标志(0:未占用，1:已占用)

    @TableField(value="benefit_mny")
    private BigDecimal benefitMny;
    @TableField(value="topic_type_id")
    private Long topicTypeId;
    @TableField(value="topic_type_name")
    private String topicTypeName;

    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }

    public Long getTopicTypeId() {
        return topicTypeId;
    }

    public void setTopicTypeId(Long topicTypeId) {
        this.topicTypeId = topicTypeId;
    }

    public String getTopicTypeName() {
        return topicTypeName;
    }

    public void setTopicTypeName(String topicTypeName) {
        this.topicTypeName = topicTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getTopicName() {
        return topicName;
    }

    public void setTopicName(String topicName) {
        this.topicName = topicName;
    }

    public Date getPlanTermStart() {
        return planTermStart;
    }

    public void setPlanTermStart(Date planTermStart) {
        this.planTermStart = planTermStart;
    }

    public Date getPlanTermEnd() {
        return planTermEnd;
    }

    public void setPlanTermEnd(Date planTermEnd) {
        this.planTermEnd = planTermEnd;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getTopicExecUser() {
        return topicExecUser;
    }

    public void setTopicExecUser(String topicExecUser) {
        this.topicExecUser = topicExecUser;
    }
    public String getBriefScheme() {
        return briefScheme;
    }

    public void setBriefScheme(String briefScheme) {
        this.briefScheme = briefScheme;
    }
    public String getIncomeBasis() {
        return incomeBasis;
    }

    public void setIncomeBasis(String incomeBasis) {
        this.incomeBasis = incomeBasis;
    }
    public String getManagerOpinion() {
        return managerOpinion;
    }

    public void setManagerOpinion(String managerOpinion) {
        this.managerOpinion = managerOpinion;
    }
    public Integer getDepartmentConsentFlag() {
        return departmentConsentFlag;
    }

    public void setDepartmentConsentFlag(Integer departmentConsentFlag) {
        this.departmentConsentFlag = departmentConsentFlag;
    }
    public String getDepartmentOpinion() {
        return departmentOpinion;
    }

    public void setDepartmentOpinion(String departmentOpinion) {
        this.departmentOpinion = departmentOpinion;
    }
    public Integer getLeaderConsentFlag() {
        return leaderConsentFlag;
    }

    public void setLeaderConsentFlag(Integer leaderConsentFlag) {
        this.leaderConsentFlag = leaderConsentFlag;
    }
    public String getLeaderOpinion() {
        return leaderOpinion;
    }

    public void setLeaderOpinion(String leaderOpinion) {
        this.leaderOpinion = leaderOpinion;
    }
    public Integer getCalculationOccupyFlag() {
        return calculationOccupyFlag;
    }

    public void setCalculationOccupyFlag(Integer calculationOccupyFlag) {
        this.calculationOccupyFlag = calculationOccupyFlag;
    }
    public Integer getRewardOccupyFlag() {
        return rewardOccupyFlag;
    }

    public void setRewardOccupyFlag(Integer rewardOccupyFlag) {
        this.rewardOccupyFlag = rewardOccupyFlag;
    }
    
}
